import React from 'react';
import PropTypes from 'prop-types';
import Logo from '../../../../assets/logos/logo.svg';

function classNames(...classes) {
    return classes.filter(Boolean).join(' ')
  }

function displayNavItems(navigation) {

    return navigation.map((item) => (
        <a
          key={item.name}
          href={item.href}
          className={classNames(
            item.current ? 'bg-gray-100 text-gray-900' : 'text-gray-600 hover:bg-gray-50 hover:text-gray-900',
            'group flex items-center px-2 py-2 text-sm font-medium rounded-md'
          )}
        >
          <item.icon
            className={classNames(
              item.current ? 'text-gray-800' : 'text-gray-400 group-hover:text-gray-500',
              'mr-3 flex-shrink-0 h-6 w-6'
            )}
            aria-hidden="true"
          />
          {item.name}
        </a>
      ))
}

const DesktopSideBar = ({ navigation, miscellaneousNavigation }) => (
    <div className="hidden md:flex md:flex-shrink-0 ">
        <div className="flex flex-col w-64">
          {/* Sidebar component, swap this element with another sidebar if you like */}
          <div className="flex flex-col flex-grow pb-4 bg-white overflow-y-auto">
            <div className="flex items-center flex-shrink-0 px-4 h-16 border-b border-gray-200">
              <img
                className="h-8 w-auto"
                src={Logo}
                alt="Otto"
              />
            </div>
            <div className="mt-5 space-y-4">
              <nav className="flex-1 px-2 bg-white space-y-1">
                {displayNavItems(navigation)}
              </nav>
              <div className="border-b border-gray-200"/>

              <nav className="flex-1 px-2 bg-white space-y-1">
                {displayNavItems(miscellaneousNavigation)}
              </nav>
            </div>
          </div>
        </div>
      </div>
);

DesktopSideBar.propTypes = {
    navigation: PropTypes.arrayOf(PropTypes.shape({})),
    miscellaneousNavigation: PropTypes.arrayOf(PropTypes.shape({}))
}
export default DesktopSideBar;