import React from "react";
import PropTypes from "prop-types";

function classNames(...classes) {
  return classes.filter(Boolean).join(" ");
}
function displayNavItems(navigation) {
    return navigation.map((item) => (
        <a
          key={item.name}
          href={item.href}
          className={classNames(
            item.current
              ? "bg-gray-100 text-gray-900"
              : "text-gray-600 hover:bg-gray-50 hover:text-gray-900",
            "group flex items-center px-2 py-2 text-base font-medium rounded-md"
          )}
        >
          <item.icon
            className={classNames(
              item.current
                ? "text-gray-500"
                : "text-gray-400 group-hover:text-gray-500",
              "mr-4 flex-shrink-0 h-6 w-6"
            )}
            aria-hidden="true"
          />
          {item.name}
        </a>
      ))
}
const MobileSideBar = ({ navigation, miscellaneousNavigation }) => (
  <div className="mt-5 flex-1 h-0 overflow-y-auto space-y-2">
    <nav className="px-2 space-y-1">
      {displayNavItems(navigation)}
    </nav>
    <div className="border-b border-gray-200"/>
    <nav className="px-2 space-y-1">
      {displayNavItems(miscellaneousNavigation)}
    </nav>
  </div>
);

MobileSideBar.propTypes = {
  navigation: PropTypes.arrayOf(PropTypes.shape({})),
  miscellaneousNavigation: PropTypes.arrayOf(PropTypes.shape({})),
};
export default MobileSideBar;
